# Noid API

```python
from xgorn_api import NoidAPI

api = NoidAPI()
api.api_key = 'your-api-key'

api.ouo_bypass('https://ouo.io/4ZuwGMc')
```

**Everything** are based on the documentation!

## Installation

```
pip install xgorn-api
```
